==> JohnsonKinaseData_0.99.0.tar.gz: JohnsonKinaseData/inst/doc/JohnsonKinaseData.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----installation, eval=FALSE-------------------------------------------------
#  if (!require("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  
#  BiocManager::install("ExperimentHub")
#  BiocManager::install("JohnsonKinaseData")

## ----load-pwm-----------------------------------------------------------------
library(JohnsonKinaseData)
pwms <- getKinasePWM()

head(names(pwms))

## ----pwm-example--------------------------------------------------------------
pwms[["PLK2"]]

## ----pwm-st-------------------------------------------------------------------
pwms2 <- getKinasePWM(includeSTfavorability=FALSE)

## -----------------------------------------------------------------------------
ppeps <- c("SAGLLS*DEDC", "GDS*ND", "EKGDSN__", "___LySDEDC", "EKGtS*N")

sites <- processPhosphopeptides(ppeps)

sites

## -----------------------------------------------------------------------------
processPhosphopeptides("KART*LLS*DEC")
processPhosphopeptides("KART*LLS*DEC", onlyCentralAcceptor=FALSE)

## -----------------------------------------------------------------------------
selected <- sites |> 
  dplyr::filter(acceptor %in% c('S','T')) |> 
  dplyr::pull(processed)

scores <- scorePhosphosites(pwms, selected)

dim(scores)

head(scores[,1:5])

## -----------------------------------------------------------------------------
scores <- scorePhosphosites(pwms, selected, BPPARAM=BiocParallel::SerialParam())

## -----------------------------------------------------------------------------
scores <- scorePhosphosites(pwms, selected, scoreType="percentile")

head(scores[,1:5])

## ----session-info-------------------------------------------------------------
sessionInfo()

==> JohnsonKinaseData_1.1.0.tar.gz: JohnsonKinaseData/inst/doc/JohnsonKinaseData.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----installation, eval=FALSE-------------------------------------------------
#  if (!require("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  
#  BiocManager::install("ExperimentHub")
#  BiocManager::install("JohnsonKinaseData")

## ----load-pwm-----------------------------------------------------------------
library(JohnsonKinaseData)
pwms <- getKinasePWM()

head(names(pwms))

## ----pwm-example--------------------------------------------------------------
pwms[["PLK2"]]

## ----pwm-st-------------------------------------------------------------------
pwms2 <- getKinasePWM(includeSTfavorability=FALSE)

## -----------------------------------------------------------------------------
ppeps <- c("SAGLLS*DEDC", "GDtND", "EKGDSN__", "HKRNyGsDER", "PEKS*GyNV")

sites <- processPhosphopeptides(ppeps)

sites

## -----------------------------------------------------------------------------
sites <- processPhosphopeptides(ppeps, onlyCentralAcceptor=FALSE)

sites

## -----------------------------------------------------------------------------
selected <- sites |> 
  dplyr::filter(acceptor %in% c('S','T')) |> 
  dplyr::pull(processed)

scores <- scorePhosphosites(pwms, selected)

dim(scores)

scores[,1:5]

## -----------------------------------------------------------------------------
scores <- scorePhosphosites(pwms, selected, BPPARAM=BiocParallel::SerialParam())

## -----------------------------------------------------------------------------
scores <- scorePhosphosites(pwms, selected, scoreType="percentile")

scores[,1:5]

## ----session-info-------------------------------------------------------------
sessionInfo()
